from setuptools import setup
setup(
    name = "slowaes",
    version = "0.1a1",
    license = "Apache License, Version 2.0",
    py_modules=['aes'],
    url = "http://code.google.com/p/slowaes/",
    author = "Josh Davis, Alex Martelli",
    description = "implementation of AES in Python",
)

